import 'dart:typed_data';

import 'package:domain/entity/feedback_detail_entity.dart';
import 'package:domain/entity/form_option_entity.dart';
import 'package:plugin_platform/platform_export.dart';
import 'package:plugin_platform/http/dio_engine.dart';
import 'package:plugin_platform/http/http_result.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/util.dart';

import '../constants/api_constants.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:plugin_basic/provider/http_provider/http_provider.dart';
import '../entity/form_content_entity.dart';
import '../entity/form_detail_entity.dart';
import '../entity/form_list_entity.dart';
import '../entity/form_submitted_page_entity.dart';
import '../entity/id_name_entity.dart';

part 'facility_repository.g.dart';

@Riverpod(keepAlive: true)
FacilityRepository facilityRepository(Ref ref) {
  final dioEngine = ref.watch(dioEngineProvider);
  return FacilityRepository(dioEngine: dioEngine);
}

/*
 * 设施的数据仓库
 */
class FacilityRepository {
  DioEngine dioEngine;

  FacilityRepository({required this.dioEngine});


  Future<HttpResult<IdNameEntity>> fetchFormApplyList({
    CancelToken? cancelToken,
  }) async {
    final result = await dioEngine.requestNetResult(
      ApiConstants.apiFormList,
      method: HttpMethod.GET,
      cancelToken: cancelToken,
    );

    if (result.isSuccess) {
      final jsonList = result.getListJson();

      //获取List数据 需要转换一次
      var list = jsonList
          ?.map((value) {
        if (value is Map<String, dynamic>) {
          return IdNameEntity.fromJson(value);
        } else {
          return null;
        }
      })
          .where((item) => item != null)
          .cast<IdNameEntity>()
          .toList();

      return result.convert<IdNameEntity>(list: list);
    }
    return result.convert<IdNameEntity>();
  }

}
